package envoy.client.ui;

import java.awt.Dimension;
import java.awt.Graphics;

import javax.swing.JButton;

import envoy.client.Settings;
import envoy.client.SettingsItem;

/**
 * This Component can be used to toggle between two options. e.g. on and
 * off.<br>
 * <br>
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>PrimaryToggleSwitch.java</strong><br>
 * Created: <strong>21 Dec 2019</strong><br>
 * 
 * @author Maximilian K&auml;fer
 * @since Envoy v0.3-alpha
 */
public class PrimaryToggleSwitch extends JButton {

	private boolean state;

	private static final long serialVersionUID = -721155303106833184L;

	/**
	 * This is the constructor for the PrimaryToggleSwitch.
	 * 
	 * @param settingsItem
	 * @since Envoy v0.3-alpha
	 */
	public PrimaryToggleSwitch(SettingsItem<Boolean> settingsItem) {
		setPreferredSize(new Dimension(50, 25));
		setMinimumSize(new Dimension(50, 25));
		setMaximumSize(new Dimension(50, 25));

		setBorderPainted(false);
		setFocusPainted(false);
		setContentAreaFilled(false);

		state = settingsItem.get();
		addActionListener((evt) -> { state = !state; settingsItem.set(state); revalidate(); repaint(); });
	}

	@Override
	public void paintComponent(Graphics g) {
		g.setColor(state ? Color.GREEN : Color.LIGHT_GRAY);
		g.fillRoundRect(0, 0, getWidth(), getHeight(), 25, 25);

		g.setColor(Settings.getInstance().getThemes().get(Settings.getInstance().getCurrentTheme()).getInteractableBackgroundColor());

		if (state)
			g.fillRoundRect(25, 0, 25, 25, 25, 25);
		else
			g.fillRoundRect(0, 0, 25, 25, 25, 25);
	}
}